import type { QueueConsumerDependencies } from '@message-queue-toolkit/core';
import { type ConsumeOptions, type ConsumerOptions } from '@platformatic/kafka';
import { AbstractKafkaService, type BaseKafkaOptions } from './AbstractKafkaService.ts';
import type { KafkaHandlerRouting } from './handler-container/KafkaHandlerRoutingBuilder.ts';
import type { KafkaDependencies, TopicConfig } from './types.ts';
export type KafkaConsumerDependencies = KafkaDependencies & Pick<QueueConsumerDependencies, 'transactionObservabilityManager'>;
export type KafkaConsumerOptions<TopicsConfig extends TopicConfig[]> = BaseKafkaOptions & Omit<ConsumerOptions<string, object, string, string>, 'deserializers' | 'autocommit' | 'bootstrapBrokers'> & Omit<ConsumeOptions<string, object, string, string>, 'topics'> & {
    handlers: KafkaHandlerRouting<TopicsConfig>;
};
export declare abstract class AbstractKafkaConsumer<TopicsConfig extends TopicConfig[]> extends AbstractKafkaService<TopicsConfig, KafkaConsumerOptions<TopicsConfig>> {
    private readonly consumer;
    private consumerStream?;
    private readonly transactionObservabilityManager;
    private readonly handlerContainer;
    constructor(dependencies: KafkaConsumerDependencies, options: KafkaConsumerOptions<TopicsConfig>);
    init(): Promise<void>;
    close(): Promise<void>;
    private consume;
    private tryToConsume;
    private buildTransactionName;
    private getRequestContext;
}
